import type { ChangeEvent } from "react";
import Person from "./Person/Person";
import IPerson from "../../interfaces/IPerson";

type People = (IPerson & { hobby: string })[];

interface Props {
  people: People;
  onClickHeader(id: string): void;
  onChangeName(e: ChangeEvent<HTMLInputElement>, id: string): void;
  onRemove(id: string): void;
}

const People = ({
  people,
  onClickHeader,
  onChangeName,
  onRemove,
}: Props): JSX.Element => {
  return (
    <div>
      {people.map((person) => {
        return (
          <Person
            key={person.id}
            name={person.name}
            age={person.age}
            onClickHeader={() => {
              onClickHeader(person.id);
            }}
            onChangeHandler={(e) => {
              onChangeName(e, person.id);
            }}
            onRemoveHandler={() => {
              onRemove(person.id);
            }}
          >
            hobby:{person.hobby}
          </Person>
        );
      })}
    </div>
  );
};

export default People;
