import type { ChangeEvent } from "react";
import { useState } from "react";
import "./App.css";
import IPerson from "../interfaces/IPerson";
import People from "../components/People/People";
import Counter from "../components/Counter/Counter";
import ToggleButton from "../components/ToggleButton/ToggleButton";

type State = (IPerson & {
  hobby: string;
})[];

const App = () => {
  const [people, setPeople] = useState<State>([
    {
      name: "John",
      age: 33,
      hobby: "video games",
      id: "j11",
    },
    {
      name: "Jane",
      age: 28,
      hobby: "video games",
      id: "j12",
    },
    {
      name: "Dmitry",
      age: 33,
      hobby: "video games",
      id: "j13",
    },
    {
      name: "Kamisama",
      age: 28,
      hobby: "video games",
      id: "j14",
    },
  ]);

  const [isShowPeople, setIsShowPeople] = useState(true);

  const increaseAge = (id: string): void => {
    const index = people.findIndex((person) => person.id === id);
    const person = { ...people[index] };
    person.age++;
    const copyPeople = [...people];
    copyPeople[index] = person;

    setPeople(copyPeople);
  };

  const changeNameHandler = (e: ChangeEvent<HTMLInputElement>, id: string) => {
    const index = people.findIndex((person) => person.id === id);
    const copyPeople = structuredClone(people);
    copyPeople[index].name = e.target.value;

    setPeople(copyPeople);
  };

  const toggleIsShowPeople = (): void => {
    setIsShowPeople(!isShowPeople);
  };

  const removePerson = (id: string): void => {
    const index = people.findIndex((person) => person.id === id);
    const copyPeople = structuredClone(people);
    copyPeople.splice(index, 1);
    setPeople(copyPeople);
  };

  const peopleList = isShowPeople ? (
    <People
      onChangeName={changeNameHandler}
      onClickHeader={increaseAge}
      onRemove={removePerson}
      people={people}
    />
  ) : null;
  const showText = <span>"Show people"</span>;
  return (
    <>
      <div className="App">
        <ToggleButton
          showText={showText}
          onClick={toggleIsShowPeople}
          isToggle={isShowPeople}
        />
        <Counter value={people.length} />
        {peopleList}
      </div>
    </>
  );
};

export default App;
